#ifndef _DialogFileChooser_h
#define _DialogFileChooser_h

/*
 *	subtitleeditor -- a tool to create or edit subtitle
 *
 *	http://home.gna.org/subtitleeditor/
 *	https://gna.org/projects/subtitleeditor/
 *
 *	Copyright @ 2005-2008, kitone
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 3 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "DialogUtility.h"

/*
 *
 */
class DialogOpenDocument : public DialogFileChooser
{
public:
	DialogOpenDocument();
};

/*
 *
 */
class DialogSaveDocument : public DialogFileChooser
{
public:
	DialogSaveDocument();
};

/*
 *
 */
class DialogOpenVideo : public Gtk::FileChooserDialog
{
public:
	DialogOpenVideo();
	~DialogOpenVideo();
};

/*
 * Waveform or Video/Audio
 */
class DialogOpenWaveform : public Gtk::FileChooserDialog
{
public:
	DialogOpenWaveform();
	~DialogOpenWaveform();
};

#endif//_DialogFileChooser_h

